Changed ``hermitian => conjugate``

Now one should use ``H.transpose(conjugate=True, ...)``
instead. The Hermitian argument did not make sense, since
the transpose was implicit of the function name.

It is now also more obvious how ``conjugate=..., spin=...``
works together.

Also, all arguments to this method are forced keywords.

A ``len(H) == H.no * 4`` for Nambu spin configuration.

The diagonalization of the Hamiltonian will return
an eigenvalue symmetric spectrum (about E=0).
Hence this one will be dependent on the shift of the
spectrum.
